@@ -1,4 +1,3 @@
-import os
 from functools import wraps
 from typing import Callable
 
@@ -19,12 +18,12 @@ def authenticated(func: Callable[[Player, HttpRequest], BaseModel]):
         access_token = request.headers.get(access_header)
         client_token = request.headers.get(client_header)
         if not all((access_header, client_header)):
-            raise HttpResponseForbidden
+            return HttpResponseForbidden()
 
         try:
             player: Player = Player.objects.get(token__access=access_token, token__client=client_token)
         except (Player.DoesNotExist, Player.MultipleObjectsReturned):
-            raise HttpResponseForbidden
+            return HttpResponseForbidden()
 
         response = func(player, request)
         return response
